@@ -9,8 +9,8 @@
 #global OU (OU1), multiple regime OU (OUM), multiple sigmas (OUMV), multiple alphas (OUMA), 
 #and the multiple alphas and sigmas (OUMVA). 
 
-OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA"),root.station=TRUE, ip=1, plot.resid=TRUE, eigenvect=TRUE){
-	
+OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA"), root.station=TRUE, ip=1, plot.resid=TRUE, clade=NULL, eigenvect=FALSE){
+
 	#Makes sure the data is in the same order as the tip labels
 	data<-data.frame(data[,2], data[,3], row.names=data[,1])
 	data<-data[phy$tip.label,]
@@ -18,6 +18,22 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 	#Values to be used throughout
 	n=max(phy$edge[,1])
 	ntips=length(phy$tip.label)
+	
+	#Will label the clade of interest
+	if(is.null(clade)){
+		phy=phy
+	}
+	else{
+		node<-mrca(phy)[clade[1],clade[2]]
+		int<-c(node,Descendants(phy,node, "all"))
+		tips<-int[int<ntips]
+		data[,1]<-1
+		data[tips,1]<-2
+		int<-int[int>ntips]
+		phy$node.label<-rep(1,phy$Nnode)
+		pp<-int-length(phy$tip.label)
+		phy$node.label[pp]<-2
+	}
 	int.states<-factor(phy$node.label)
 	phy$node.label=as.numeric(int.states)
 	tip.states<-factor(data[,1])
@@ -111,7 +127,6 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 			index.mat[2,1:k]<-2
 			bool=root.station
 		}
-		
 		if (model == "OUMV") {
 			np=k+1
 			index<-matrix(TRUE,2,k)
@@ -119,7 +134,6 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 			index.mat[2,1:k]<-2:(k+1)
 			bool=root.station
 		}
-		
 		if (model == "OUMA") {
 			np=k+1
 			index<-matrix(TRUE,2,k)
@@ -127,7 +141,6 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 			index.mat[2,1:k]<-k+1
 			bool=root.station
 		}
-		
 		if (model == "OUMVA") {
 			np=k*2
 			index<-matrix(TRUE,2,k)
@@ -140,7 +153,7 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 	#Likelihood function for estimating model parameters
 	dev<-function(p){
 		
-		Rate.mat[] <- c(p, 0.000001)[index.mat]
+		Rate.mat[] <- c(p, 0.0000000001)[index.mat]
 		
 		N<-length(x[,1])
 		V<-varcov.ou(phy, edges, Rate.mat, root.state=root.state)
@@ -159,7 +172,7 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 	#Informs the user that the optimization routine has started and starting value is being used (default=1)
 	cat("Begin subplex optimization routine -- Starting value:",ip, "\n")
 	
-	lower = rep(0.000001, np)
+	lower = rep(0.0000000001, np)
 	upper = rep(20, np)
 	
 	opts <- list("algorithm"="NLOPT_LN_SBPLX", "maxeval"="1000000", "ftol_rel"=.Machine$double.eps^0.5, "xtol_rel"=.Machine$double.eps^0.5)
@@ -170,7 +183,7 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 	#Takes estimated parameters from dev and calculates theta for each regime
 	dev.theta<-function(p){
 		
-		Rate.mat[] <- c(p, 0.000001)[index.mat]
+		Rate.mat[] <- c(p, 0.0000000001)[index.mat]
 		
 		N<-length(x[,1])
 		V<-varcov.ou(phy, edges, Rate.mat, root.state=root.state)
@@ -198,7 +211,7 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 	if (is.character(model)) {
 		if (model == "BM1"){
 			obj$AIC <- -2*obj$loglik+2*(np+1)
-			obj$AICc <- -2*obj$loglik+(2*(np+k)*(ntips/(ntips-(np+k)-1)))
+			obj$AICc <- -2*obj$loglik+(2*(np+1)*(ntips/(ntips-(np+1)-1)))
 			obj$Param.est <- matrix(out$solution[index.mat], dim(index.mat))
 			rownames(obj$Param.est)<-c("alpha","sigma.sq")
 			colnames(obj$Param.est) <- levels(int.states)
@@ -208,7 +221,7 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 		}
 		if (model == "BMS"){
 			obj$AIC <- -2*obj$loglik+2*(np+1)
-			obj$AICc <- -2*obj$loglik+(2*(np+k)*(ntips/(ntips-(np+k)-1)))
+			obj$AICc <- -2*obj$loglik+(2*(np+1)*(ntips/(ntips-(np+1)-1)))
 			obj$Param.est <- matrix(out$solution[index.mat], dim(index.mat))
 			rownames(obj$Param.est)<-c("alpha","sigma.sq")
 			colnames(obj$Param.est) <- levels(int.states)
@@ -219,7 +232,7 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 		if (root.station == TRUE){
 			if (model == "OU1"){
 				obj$AIC <- -2*obj$loglik+2*(np+1)
-				obj$AICc <- -2*obj$loglik+(2*(np+k)*(ntips/(ntips-(np+k)-1)))
+				obj$AICc <- -2*obj$loglik+(2*(np+1)*(ntips/(ntips-(np+1)-1)))
 				obj$Param.est<- matrix(out$solution[index.mat], dim(index.mat))
 				rownames(obj$Param.est)<-c("alpha","sigma.sq")
 				colnames(obj$Param.est)<-levels(int.states)
@@ -229,8 +242,8 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 		}
 		if (root.station == FALSE){
 			if (model == "OU1"){
-				obj$AIC <- -2*obj$loglik+2*(np+1)
-				obj$AICc <- -2*obj$loglik+(2*(np+k)*(ntips/(ntips-(np+k)-1)))
+				obj$AIC <- -2*obj$loglik+2*(np+2)
+				obj$AICc <- -2*obj$loglik+(2*(np+2)*(ntips/(ntips-(np+2)-1)))
 				obj$Param.est<- matrix(out$solution[index.mat], dim(index.mat))
 				rownames(obj$Param.est)<-c("alpha","sigma.sq")
 				colnames(obj$Param.est)<-levels(int.states)
@@ -242,8 +255,8 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 		}
 		if (root.station == FALSE){
 			if (model == "OUM"| model == "OUMV"| model == "OUMA" | model == "OUMVA"){ 
-				obj$AIC <- -2*obj$loglik+2*(np+k)
-				obj$AICc <- -2*obj$loglik+(2*(np+k)*(ntips/(ntips-(np+k)-1)))
+				obj$AIC <- -2*obj$loglik+2*(np+k+1)
+				obj$AICc <- -2*obj$loglik+(2*(np+k+1)*(ntips/(ntips-(np+k+1)-1)))
 				obj$Param.est<- matrix(out$solution[index.mat], dim(index.mat))
 				rownames(obj$Param.est)<-c("alpha","sigma.sq")
 				colnames(obj$Param.est)<-levels(int.states)
@@ -279,17 +292,19 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 	hess.eig<-eigen(h,symmetric=TRUE)
 	#If eigenvect is TRUE then the eigenvector and index matrix will appear in the list of objects 
 	obj$eigval<-signif(hess.eig$values,2)
-	if(eigenvect==TRUE){
+	if(any(obj$eigval<0) || eigenvect){
 		obj$eigvect<-round(hess.eig$vectors, 2)
 		obj$index.matrix <- index.mat
 		rownames(obj$index.matrix)<-c("alpha","sigma.sq")
 		colnames(obj$index.matrix)<-levels(int.states)
-	} 
-	#If any eigenvalue is less than 0 then the solution is not the maximum likelihood solution
-	if(any(obj$eigval<0)){
-		obj$Diagnostic<-'The objective function may be at a saddle point -- check eigenvectors or try a simpler model'
+		#If any eigenvalue is less than 0 then the solution is not the maximum likelihood solution
+    if (any(obj$eigval<0)) {
+		  obj$Diagnostic<-'The objective function may be at a saddle point -- check eigenvectors or try a simpler model'
+    }
+    else{obj$Diagnostic<-'Arrived at a reliable solution'}
+
 	}
 	else{obj$Diagnostic<-'Arrived at a reliable solution'}
 	
 	obj
-}
+}
\ No newline at end of file
