@@ -3,7 +3,7 @@
 #written by Jeremy M. Beaulieu
 
 varcov.ou<-function(phy, edges, Rate.mat, root.state){
-
+	
 	n=max(phy$edge[,1])
 	ntips=length(phy$tip.label)
 	k=max(as.numeric(phy$node.label))
@@ -19,10 +19,8 @@ varcov.ou<-function(phy, edges, Rate.mat, root.state){
 	nodecode=matrix(c(ntips+1,0,root.state),1,3)
 
 	for(i in 1:length(edges[,1])){
-		
-		anc = edges[i, 2]
-		desc = edges[i, 3]
-		
+		anc = edges[i,2]
+		desc = edges[i,3]
 		newregime=which(edges[i,5:(k+4)]==1)
 		current=edges[i,4]
 		
@@ -39,24 +37,25 @@ varcov.ou<-function(phy, edges, Rate.mat, root.state){
 		if(oldregime==newregime){
 			newtime=current
 			nodevar1[i]=alpha[oldregime]*(newtime-oldtime)
-			nodevar2[i]=sigma[oldregime]*exp(2*alpha[oldregime]*(newtime+oldtime)/2)*(newtime-oldtime)
+			nodevar2[i]=sigma[oldregime]*((exp(2*alpha[oldregime]*newtime)-exp(2*alpha[oldregime]*oldtime))/(2*alpha[oldregime]))
 		}
 		else{
 			newtime=current-((current-oldtime)/2)
-			epoch1a=(alpha[oldregime])*(newtime-oldtime)
-			epoch1b=sigma[oldregime]*exp(2*alpha[oldregime]*(newtime+oldtime)/2)*(newtime-oldtime)
+			epoch1a=alpha[oldregime]*(newtime-oldtime)
+			epoch1b=sigma[oldregime]*((exp(2*alpha[oldregime]*newtime)-exp(2*alpha[oldregime]*oldtime))/(2*alpha[oldregime]))
 			oldtime=newtime
 			newtime=current
 			epoch2a=alpha[newregime]*(newtime-oldtime)
-			epoch2b=sigma[newregime]*exp(2*alpha[newregime]*(newtime+oldtime)/2)*(newtime-oldtime)
+			epoch2b=sigma[newregime]*((exp(2*alpha[newregime]*newtime)-exp(2*alpha[newregime]*oldtime))/(2*alpha[newregime]))
 			nodevar1[i]<-epoch1a+epoch2a
 			nodevar2[i]<-epoch1b+epoch2b
 		}
 		oldregime=newregime
 		n.cov1[edges[i,2],edges[i,3]]=nodevar1[i]
 		n.cov2[edges[i,2],edges[i,3]]=nodevar2[i]
-	}
 		
+	}
+
 	#Remove nodecode matrix from memory
 	rm(nodecode)
 	vcv1<-mat.gen(n.cov1,phy)
@@ -64,13 +63,12 @@ varcov.ou<-function(phy, edges, Rate.mat, root.state){
 	vcv<-exp(-2*diag(vcv1))*vcv2
 	rm(vcv1)
 	rm(vcv2)
-
+	
 	vcv
 	
 }
 
 #Utility for building a summary matrix -- slow for now, need to work on speeding up
-
 mat.gen<-function(mat,phy){
 	
 	n=max(phy$edge[,1])
@@ -90,12 +88,14 @@ mat.gen<-function(mat,phy){
 		nn<-Ancestors(phy,i)
 		S[nn,i]<-1
 	}
+
 	#Convert to a sparse matrix
 	S<-as.matrix.csr(S)
 	
 	#Create a matrix of sums for each node
 	temp<-mat%*%S+mat
 	n.covsums=apply(as.matrix(temp), 2, sum)
+
 	rm(temp)
 	rm(mat)
 	#Generates a matrix that lists the descendants for each ancestral node
@@ -147,3 +147,41 @@ Ancestors<-function (x, node, type = c("all", "parent"))
     res
 }
 
+allChildren = function(x){
+	parent = x$edge[,1]
+	children = x$edge[,2]
+	res = vector("list", max(x$edge))
+	for(i in 1:length(parent)) res[[parent[i]]] = c(res[[parent[i]]], children[i])
+	res
+}
+
+
+Children = function(x, node){
+	if(length(node)==1) return(allChildren(x)[[node]])
+	allChildren(x)[node]
+}
+
+Descendants = function(x, node, type=c("tips","children","all")){
+    type <- match.arg(type)
+    if(type=="children") return(Children(x, node))
+    
+    desc = function(x, node, type){# ,isInternal=NULL, ch=NULL
+        isInternal = logical(max(x$edge))
+        isInternal[ unique(x$edge[,1]) ] =TRUE 
+		
+        if(!isInternal[node])return(node)
+        ch = allChildren(x)
+        res = NULL
+        while(length(node)>0){
+            tmp = unlist(ch[node])
+            res = c(res, tmp)
+            node = tmp[isInternal[tmp]]
+        }
+		if(type=="tips") return(res[!isInternal[res]])
+		res
+    }
+    if(length(node)>1) return(lapply(node, desc, x=x, type=type))
+    desc(x,node, type)
+}
+
+
